Developer Resources
===================

A compiled list of resources for new and existing developers and maintainers of the
library. If you believe a document or information is missing please check our
`issue tracker <https://github.com/bioio-devs/bioio/issues>`_.

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Contents:

   Contributing <CONTRIBUTING>
   Code of Conduct <CODE_OF_CONDUCT>
   Governance Model <GOVERNANCE>
   Mission and Values <MISSION_AND_VALUES>
